@@ -2,7 +2,7 @@ package App::RecordStream::Bio;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 1;
 __END__
@@ -20,6 +20,11 @@ App::RecordStream::Bio - A collection of record-handling tools related to biolog
     recs-fromfasta --oneline < seqs.fasta           \
         | recs-grep '{{id}} =~ /\b(POL|GAG)\b/i'    \
         | recs-tocsv -k id,sequence
+    
+    # Filter gaps from sequences
+    recs-fromfasta seqs.fasta \
+        | recs-xform '{{seq}} =~ s/-//g' \
+        | recs-tofasta > seqs-nogaps.fasta
 
 =head1 DESCRIPTION
 
@@ -33,6 +38,8 @@ them via their command line wrappers within a larger record stream pipeline.
 
 L<recs-fromfasta>
 
+L<recs-tofasta>
+
 =head1 AUTHOR
 
 Thomas Sibley E<lt>trsibley@uw.eduE<gt>
